@@ -1,26 +1,33 @@
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import os
+from os.path import basename, expanduser, isdir, isfile, join
 import re
 import sys
-from os.path import isdir, isfile, join, expanduser
+import sysconfig
+
+from ..common.compat import on_win
+from ..utils import memoized
 
-from ..utils import memoized, on_win
 
 def find_executable(executable, include_others=True):
     # backwards compatibility
     global dir_paths
 
     if include_others:
+        from ..utils import sys_prefix_unfollowed
+        prefixes = [sys_prefix_unfollowed()]
+        if sys.prefix != prefixes[0]:
+            prefixes.append(sys.prefix)
+        dir_paths = [join(p, basename(sysconfig.get_path('scripts')))
+                     for p in prefixes]
+        # Is this still needed?
         if on_win:
-            dir_paths = [join(sys.prefix, 'Scripts'),
-                         'C:\\cygwin\\bin']
-        else:
-            dir_paths = [join(sys.prefix, 'bin')]
+            dir_paths.append('C:\\cygwin\\bin')
     else:
         dir_paths = []
 
-    dir_paths.extend(os.environ['PATH'].split(os.pathsep))
+    dir_paths.extend(os.environ[str('PATH')].split(os.pathsep))
 
     for dir_path in dir_paths:
         if on_win:
@@ -34,14 +41,20 @@ def find_executable(executable, include_others=True):
                 return expanduser(path)
     return None
 
+
 @memoized
 def find_commands(include_others=True):
+
     if include_others:
+        from ..utils import sys_prefix_unfollowed
+        prefixes = [sys_prefix_unfollowed()]
+        if sys.prefix != prefixes[0]:
+            prefixes.append(sys.prefix)
+        dir_paths = [join(p, basename(sysconfig.get_path('scripts')))
+                     for p in prefixes]
+        # Is this still needed?
         if on_win:
-            dir_paths = [join(sys.prefix, 'Scripts'),
-                         'C:\\cygwin\\bin']
-        else:
-            dir_paths = [join(sys.prefix, 'bin')]
+            dir_paths.append('C:\\cygwin\\bin')
     else:
         dir_paths = []
 
