@@ -1,16 +1,20 @@
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import errno
+import json
 import logging
 import os
+from os.path import isdir, isfile, join
 import re
 import sys
 import time
 import warnings
-from os.path import isdir, isfile, join
 
-from .install import linked, dist2quad
-from .exceptions import CondaHistoryError, CondaFileIOError
+from .base.constants import DEFAULTS_CHANNEL_NAME
+from .common.compat import ensure_text_type, open
+from .core.linked_data import linked
+from .exceptions import CondaFileIOError, CondaHistoryError
+from .models.dist import Dist
 
 log = logging.getLogger(__name__)
 
@@ -21,7 +25,7 @@ class CondaHistoryWarning(Warning):
 
 def write_head(fo):
     fo.write("==> %s <==\n" % time.strftime('%Y-%m-%d %H:%M:%S'))
-    fo.write("# cmd: %s\n" % (' '.join(sys.argv)))
+    fo.write("# cmd: %s\n" % (' '.join(ensure_text_type(s) for s in sys.argv)))
 
 
 def is_diff(content):
@@ -33,8 +37,9 @@ def pretty_diff(diff):
     removed = {}
     for s in diff:
         fn = s[1:]
-        name, version, _, channel = dist2quad(fn)
-        if channel != 'defaults':
+        dist = Dist(fn)
+        name, version, _, channel = dist.quad
+        if channel != DEFAULTS_CHANNEL_NAME:
             version += ' (%s)' % channel
         if s.startswith('-'):
             removed[name.lower()] = version
@@ -85,12 +90,12 @@ class History(object):
         try:
             self.init_log_file()
             try:
-                last = self.get_state()
+                last = set(self.get_state())
             except CondaHistoryError as e:
                 warnings.warn("Error in %s: %s" % (self.path, e),
                               CondaHistoryWarning)
                 return
-            curr = set(linked(self.prefix))
+            curr = set(map(str, linked(self.prefix)))
             if last == curr:
                 # print a head when a blank env is first created to preserve history
                 if enter_or_exit == 'exit' and self.file_is_empty():
@@ -153,7 +158,7 @@ class History(object):
                 if m:
                     action, specs = m.groups()
                     item['action'] = action
-                    item['specs'] = eval(specs)
+                    item['specs'] = json.loads(specs.replace("'", '"'))
             if 'cmd' in item:
                 res.append(item)
         return res
@@ -214,7 +219,7 @@ class History(object):
             removed = {}
             if is_diff(content):
                 for pkg in content:
-                    name, version, build, channel = dist2quad(pkg[1:])
+                    name, version, build, channel = Dist(pkg[1:]).quad
                     if pkg.startswith('+'):
                         added[name.lower()] = (version, build, channel)
                     elif pkg.startswith('-'):
@@ -265,5 +270,6 @@ class History(object):
 
 if __name__ == '__main__':
     from pprint import pprint
-    with History(sys.prefix) as h:
-        pprint(h.get_user_requests())
+    # Don't use in context manager mode---it augments the history every time
+    h = History(sys.prefix)
+    pprint(h.get_user_requests())
